@@ -4,12 +4,15 @@ module System.Taffybar.Widgets.PollingGraph (
   -- * Types
   GraphHandle,
   GraphConfig(..),
+  GraphDirection(..),
+  GraphStyle(..),
   -- * Constructors and accessors
   pollingGraphNew,
   defaultGraphConfig
   ) where
 
 import Control.Concurrent
+import qualified Control.Exception.Enclosed as E
 import Control.Monad ( forever )
 import Graphics.UI.Gtk
 
@@ -24,9 +27,11 @@ pollingGraphNew cfg pollSeconds action = do
 
   _ <- on da realize $ do
        _ <- forkIO $ forever $ do
-         sample <- action
-         graphAddSample h sample
+         esample <- E.tryAny action
+         case esample of
+           Left _ -> return ()
+           Right sample -> graphAddSample h sample
          threadDelay $ floor (pollSeconds * 1000000)
        return ()
 
-  return da
\ No newline at end of file
+  return da
